@@ -32,6 +32,7 @@ comp_pos_put_etc_before = False
 comp_end = [comp_pos_npr_in]
 method_all = ['1dist', 'filler', 'prop']
 method = '1dist'
+method_use_age_floor = True
 method_use_second_pass = True
 pop_age = 'Age'
 pop_birth = 'BTH'
@@ -111,6 +112,7 @@ def is_method(x):
 
     return None
 
+is_bool_afloor = lambda x: is_bool(x, 'method_use.age_floor')
 is_bool_mu2p = lambda x: is_bool(x, 'method_use.second_pass')
 is_containing_comp_end = lambda x: is_list_containing(x, 'comp.end', False)
 is_containing_netc = lambda x: is_list_containing(x, 'comp_neg.etc', False)
@@ -174,6 +176,7 @@ _global_config = {
     },
     'method': method,
     'method_use': {
+        'age_floor': method_use_age_floor,
         'second_pass': method_use_second_pass
     },
     'pop': {
@@ -416,6 +419,16 @@ _registered_options = {
             "or 'prop'.",
         validator = is_method
     ),
+    'method_use.age_floor': RegisteredOption(
+        key = 'method_use.age_floor',
+        defval = method_use_age_floor,
+        doc =\
+            "\n (bool)\n    " +\
+            "(True by default) If True, then the estime2 package " +\
+            "uses age.floor option when calculating the minimum " +\
+            "neighbouring age for the problematic record.",
+        validator = is_bool_afloor
+    ),
     'method_use.second_pass': RegisteredOption(
         key = 'method_use.second_pass',
         defval = method_use_second_pass,
