@@ -1459,10 +1459,11 @@ def calculate_ages_to_modify_and_counter(
     Examples
     --------
     >>> # age.down_to == 40
+    >>> # age.floor == 50
     >>> # age.max == 99
     >>> age1 = Age(97)
     >>> age2 = Age('100+') # maximum age
-    >>> set_option('age.floor', 65)
+    >>> set_option('method_use.age_floor', False)
     >>> result1 = calculate_ages_to_modify_and_counter(
     ...     age1, 
     ...     comp_in_comp_end = False
@@ -1499,6 +1500,7 @@ def calculate_ages_to_modify_and_counter(
     ...     'age.to_counter': [60, 99]
     ... }
     True
+    >>> set_option('method_use.age_floor', True)
     >>> set_option('age.floor', 50)
     >>> result5 = calculate_ages_to_modify_and_counter(
     ...     age1, 
@@ -1518,20 +1520,31 @@ def calculate_ages_to_modify_and_counter(
     ...     'age.to_counter': [50, 96]
     ... }
     True
+    >>> result7 = calculate_ages_to_modify_and_counter(
+    ...     Age(75), 
+    ...     comp_in_comp_end = False
+    ... )
+    >>> result7 == {
+    ...     'age.to_modify': 74, 
+    ...     'age.to_counter': [34, 73]
+    ... }
+    True
     '''
 
     age_down_to = get_option('age.down_to')
     age_floor = get_option('age.floor')
+    use_age_floor = get_option('method_use.age_floor')
     age_is_max = problematic_age.is_max()
     to_modify_age_str = str(problematic_age.get_showing_age())
     to_modify_age_int = int(to_modify_age_str) - 1
     if comp_in_comp_end:
         to_modify_age_int += 1
+    
     to_counter_age_max = to_modify_age_int - 1
-    to_counter_age_min = min(
-        age_floor, 
-        max(-1, to_modify_age_int - age_down_to)
-    )
+    max_of_either = max(-1, to_modify_age_int - age_down_to)
+    to_counter_age_min = min(age_floor, max_of_either) if use_age_floor \
+        else max_of_either
+
     to_modify_age_int_lst = None
     result = {}
     if age_is_max and not comp_in_comp_end:
