@@ -44,9 +44,7 @@ def arrange_by_lvl(df, levels, value_name):
     return result
 
 def call_tbl():
-    files_above = os.listdir('..')
-    starts_with_G = list(map(lambda x: x[0] == 'G', files_above))
-    tbl_name = np.array(files_above)[starts_with_G][0]
+    tbl_name = [x for x in os.listdir('..') if x[0] == 'G'][0]
     tbl = pd.read_excel('../' + tbl_name, sheet_name = 1)
     poptbl = ProvPopTable(tbl)
     return poptbl
@@ -576,7 +574,7 @@ def run4():
     self = call_tbl()
     comp = 'DTH'
     comp_in_comp_end = False
-    method = 'prop'
+    method = '1dist'
     pop_sex = 'Sex'
     pop_age = 'Age'
     pop_end = 'Postcensal Population'
@@ -598,6 +596,9 @@ def run4():
 
     comp_K = f"{comp}_K"
     result = []
+    max_correctables =\
+        df_comp_counter_adjust_reversed.iloc[:, -1].values.copy()
+
     if method == '1dist':
         for index, row in df_comp_counter_adjust_reversed.iterrows():
             if row[comp_J] > 0 and to_modify_val_total != 0:
@@ -605,6 +606,28 @@ def run4():
                 to_modify_val_total -= 1
             else:
                 result.append(0)
+        print("result so far:")
+        print(result)
+        use_2nd_pass = get_option('method_use.second_pass')
+        if to_modify_val_total != 0 and use_2nd_pass:
+            # The first pass wasn't enough so that to_modify_val_total
+            # didn't come down to 0.
+            # Apply the second pass only if the option says so
+            print("The second pass has started.")
+            max_correctables -= np.array(result)
+            print("df_comp_counter_adjust_reversed:")
+            print(df_comp_counter_adjust_reversed)
+            print("New max_correctables:")
+            print(max_correctables)
+            for i, item in enumerate(max_correctables):
+                if item > 0 and to_modify_val_total != 0:
+                    result[i] += 1
+                    to_modify_val_total -= 1
+                print("to_modify_val_total:")
+                print(to_modify_val_total)
+                print("result:")
+                print(result)
+
     elif method == 'filler':
         for index, row in df_comp_counter_adjust_reversed.iterrows():
             if row[comp_J] > 0 and to_modify_val_total != 0:
@@ -638,8 +661,6 @@ def run4():
             pop_end_to_compare_reversed.iloc[:, -1].values
         if comp_in_comp_end:
             pop_end_for_prop[0] = 0
-        max_correctables =\
-            df_comp_counter_adjust_reversed.iloc[:, -1].values
         
         print("pop_end_for_prop:")
         print(pop_end_for_prop)
